==> psv-8.x-2.6.tar.gz: psv/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Maintainers
 * Attention

INTRODUCTION
------------

Password Strength Visualization for Drupal.

 * For a full description of the module visit:
   https://www.drupal.org/project/psv

 * To submit bug reports and feature suggestions, or to track changes visit:
   https://www.drupal.org/project/issues/psv

REQUIREMENTS
------------

This module requires no modules outside of Drupal core.

INSTALLATION
------------

 * Install the Password Strength Visualization module as you would normally
   install a contributed Drupal module. Visit
   https://www.drupal.org/node/1897420 for further information.

CONFIGURATION
-------------

  * Configure setting Register and Cancelation User in Administration » Configuration » People:

   - Enable password strength indicator

     Must be active.

   - Register Accounts

     All options except "Administrators only".

   - Require email verification when a visitor creates an account

     Must be inactive.

  * Configure Password Strength Visualization Settings in Administration » Configuration » System » Password Strength
       Visualization Settings:

   - Enter the background image and enable/disable reverse distortion. Save
       configuration.

MAINTAINERS
-----------

Current maintainers:
 * Alexandre Dias (Saidatom) - https://www.drupal.org/u/saidatom

ATTENTION
---------

Version based on:

 * `https://github.com/codrops/PasswordStrengthVisualization/`
 * `https://github.com/codrops/PasswordStrengthVisualization/blob/master/README.md`

Most bugs have been ironed out, holes covered, features added. This module
is a work in progress. Please report bugs and suggestions, ok?

==> psv-8.x-2.9.tar.gz: psv/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Maintainers
 * Attention

INTRODUCTION
------------

Password Strength Visualization for Drupal.

 * For a full description of the module visit:
   https://www.drupal.org/project/psv

 * To submit bug reports and feature suggestions, or to track changes visit:
   https://www.drupal.org/project/issues/psv

REQUIREMENTS
------------

This module requires no modules outside of Drupal core.

INSTALLATION
------------

 * Install the Password Strength Visualization module as you would normally
   install a contributed Drupal module. Visit
   https://www.drupal.org/node/1897420 for further information.

CONFIGURATION
-------------

  * Configure setting Register and Cancelation User in
  Administration » Configuration » People:

   - Enable password strength indicator

     Must be active.

   - Register Accounts

     All options except "Administrators only".

   - Require email verification when a visitor creates an account

     Must be inactive.

  * Configure Password Strength Visualization Settings in
  Administration » Configuration » System » Password Strength
       Visualization Settings:

   - Enter the background image and enable/disable reverse distortion. Save
       configuration.

MAINTAINERS
-----------

Current maintainers:
 * Alexandre Dias (Saidatom) - https://www.drupal.org/u/saidatom

ATTENTION
---------

Version based on:

 * `https://github.com/codrops/PasswordStrengthVisualization/`
 * `https://github.com/codrops/PasswordStrengthVisualization/blob/master/README.md`

Most bugs have been ironed out, holes covered, features added. This module
is a work in progress. Please report bugs and suggestions, ok?
